@@ -13,6 +13,7 @@
     ObjectFromEntries,
     ObjectEntries,
     ReflectGet,
+    ReflectHas,
     Proxy,
   } = window.__bootstrap.primordials;
 
@@ -113,7 +114,7 @@
       },
       get(target, key) {
         if (typeof key == "symbol") return target[key];
-        if (key in target) {
+        if (ReflectHas(target, key)) {
           return ReflectGet(...new SafeArrayIterator(arguments));
         } else {
           return target.getItem(key) ?? undefined;
@@ -141,7 +142,7 @@
         if (arguments.length === 1) {
           return undefined;
         }
-        if (key in target) {
+        if (ReflectHas(target, key)) {
           return undefined;
         }
         const value = target.getItem(key);
